@@ -88,14 +88,14 @@ class BaseSearcher(object):
             raise e
 
     def search_by_multi_bool(self, must=None, must_not=None, should=None, filter=None, source_include=None,
-                             sort_field=None, offset=0, limit=1, reverse=False):
+                             sort_field=None, offset=0, limit=1):
         """
         :param must: [Term(name='xw')]
         :param must_not: [Term(name='xw')]
         :param should: [Term(name='xw')]
         :param filter: [Term(name='xw')]
         :param source_include: ['field_1', 'field_1'] 查出的结果包含哪些字段
-        :param sort_field: str 按照哪个字段升序排序(reverse=False)、生序(reverse=True)
+        :param sort_field: str 按照哪个字段升序排序('year')、降序('-year')
         :param offset: int 查询的第几页数据
         :param limit: int 每页数量
         """
@@ -119,7 +119,7 @@ class BaseSearcher(object):
             else:
                 search = search.query()
         if sort_field:
-            search = search.sort(sort_field, reverse=reverse)
+            search = search.sort(sort_field)
         _ = search[offset: offset + limit].execute()
         total = _.hits.total
         query_list = _.to_dict()['hits']['hits']
