@@ -66,6 +66,11 @@ class RedisOp(object):
         keys = get_con.set(name, value)
         return keys
 
+    def delete(self, *names):
+        get_con = get_redis_client(label=self.label, db=self.db, strict=self.strict)
+        keys = get_con.delete(*names)
+        return keys
+
     def redis_hget(self, name, key):
         get_con = get_redis_client(label=self.label, db=self.db, strict=self.strict)
         val = get_con.hget(name, key)
@@ -137,4 +142,3 @@ if __name__ == '__main__':
 
     print(keys)
     print(val)
-
