@@ -54,9 +54,9 @@ namespace = uuid.UUID('6ba7b811-9dad-11d1-80b4-00c04fd430c8')
 
 
 def get_uuid5(short_text):
-    return uuid.uuid5(namespace, short_text)
+    return str(uuid.uuid5(namespace, short_text))
 
 
 if __name__ == '__main__':
-    r = get_md5('xxx')
-    print(r)
+    r = get_uuid5('xxx')
+    print(type(r))
